@@ -270,6 +270,12 @@ class RemoteSwitch(SwitchBase):
     def unset_interface_auto_negotiation_state(self, interface_id):
         self.delete("/interfaces/" + interface_id + '/auto-negotiation')
 
+    def set_interface_lacp_force_up(self, interface_id):
+        self.put("/interfaces/" + interface_id + '/lacp-force-up')
+
+    def unset_interface_lacp_force_up(self, interface_id):
+        self.delete("/interfaces/" + interface_id + '/lacp-force-up')
+
     def add_bond(self, number):
         self.post("/bonds", data={'number': number})
 
